package com.ruoyi.jjh.declaration.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.jjh.declaration.entity.BmsDeclarationRecords;
import com.ruoyi.jjh.declaration.entity.dto.ApprovalDeclarationRecordsQueryDto;
import com.ruoyi.jjh.declaration.entity.dto.BmsApprovalInfoUpdateDto;
import com.ruoyi.jjh.declaration.entity.dto.BmsDeclarationRecordsAddDto;
import com.ruoyi.jjh.declaration.entity.dto.BmsDeclarationRecordsDto;
import com.ruoyi.jjh.declaration.entity.dto.MunicipalReviewDto;
import com.ruoyi.jjh.declaration.entity.vo.ApprovalDeclarationRecordsQueryVo;
import com.ruoyi.jjh.declaration.entity.vo.BmsDeclarationRecordsQueryVo;
import com.ruoyi.jjh.declaration.entity.vo.BmsMunicipalBureauReviewQueryVo;
import com.ruoyi.jjh.declaration.service.IBmsDeclarationRecordsService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 在线申报记录Controller
 *
 * @author farben
 * @date 2023-08-28
 */
@RestController
@RequestMapping("/system/declarationRecords")
public class BmsDeclarationRecordsController extends BaseController {
    @Autowired
    private IBmsDeclarationRecordsService bmsDeclarationRecordsService;


    /**
     * 审核列表
     *
     * @param approvalDeclarationRecordsQueryDto
     * @return {@link TableDataInfo}
     * @author emiya.xie
     * @create 2023/9/9 14:41
     */
    @GetMapping("/approvalList")
    public TableDataInfo approvalList(ApprovalDeclarationRecordsQueryDto approvalDeclarationRecordsQueryDto) {
        startPage();
        List<ApprovalDeclarationRecordsQueryVo> list = bmsDeclarationRecordsService.approvalList(approvalDeclarationRecordsQueryDto);
        return getDataTable(list);
    }

    @Log(title = "审批记录信息", businessType = BusinessType.UPDATE)
    @PutMapping("/approvalEdit")
    public AjaxResult approvalEdit(@RequestBody BmsApprovalInfoUpdateDto bmsApprovalInfoUpdateDto) {
        return toAjax(bmsDeclarationRecordsService.updateApprovalInfo(bmsApprovalInfoUpdateDto));
    }

    /**
     * 查询在线申报记录列表
     */
//    @RequiresPermissions("system:declarationRecords:list")
    @GetMapping("/list")
    public TableDataInfo list(BmsDeclarationRecordsDto bmsDeclarationRecordsDto) {
        startPage();
        List<BmsDeclarationRecordsQueryVo> list = bmsDeclarationRecordsService.selectBmsDeclarationRecordsList(bmsDeclarationRecordsDto);
        return getDataTable(list);
    }

    /**
     * 查询在线申报记录列表-政务
     */
    @GetMapping("/listRecords")
    public TableDataInfo listRecords(BmsDeclarationRecordsDto bmsDeclarationRecordsDto) {
        startPage();
        List<BmsDeclarationRecordsQueryVo> list = bmsDeclarationRecordsService.selectBmsDeclarationRecordsZwList(bmsDeclarationRecordsDto);
        return getDataTable(list);
    }

    @Log(title = "下载市局审核申报记录", businessType = BusinessType.EXPORT)
    @PostMapping("/exportMunicipalBureauReview")
    public void export(HttpServletResponse response) {
        List<BmsMunicipalBureauReviewQueryVo> list = bmsDeclarationRecordsService.selectMunicipalBureauReviewList();
        ExcelUtil<BmsMunicipalBureauReviewQueryVo> util = new ExcelUtil<BmsMunicipalBureauReviewQueryVo>(BmsMunicipalBureauReviewQueryVo.class);
        util.exportExcel(response, list, "在线申报记录数据");
    }


    /**
     * 导出在线申报记录列表
     */
//    @RequiresPermissions("system:declarationRecords:export")
    @Log(title = "在线申报记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BmsDeclarationRecordsDto bmsDeclarationRecordsDto) {
        List<BmsDeclarationRecordsQueryVo> list = bmsDeclarationRecordsService.selectBmsDeclarationRecordsList(bmsDeclarationRecordsDto);
        ExcelUtil<BmsDeclarationRecordsQueryVo> util = new ExcelUtil<BmsDeclarationRecordsQueryVo>(BmsDeclarationRecordsQueryVo.class);
        util.exportExcel(response, list, "在线申报记录数据");
    }

    /**
     * 获取在线申报记录详细信息
     */
//    @RequiresPermissions("system:declarationRecords:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(bmsDeclarationRecordsService.selectBmsDeclarationRecordsById(id));
    }

    /**
     * 新增在线申报记录
     */
//    @RequiresPermissions("system:declarationRecords:add")
    @Log(title = "在线申报记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BmsDeclarationRecordsAddDto bmsDeclarationRecordsAddDto) {
        return toAjax(bmsDeclarationRecordsService.insertBmsDeclarationRecords(bmsDeclarationRecordsAddDto));
    }

    /**
     * 修改在线申报记录
     */
//    @RequiresPermissions("system:declarationRecords:edit")
    @Log(title = "在线申报记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BmsDeclarationRecords bmsDeclarationRecords) {
        return toAjax(bmsDeclarationRecordsService.updateBmsDeclarationRecords(bmsDeclarationRecords));
    }

    @Log(title = "市级评定结果确认-old", businessType = BusinessType.UPDATE)
    @PutMapping("/municipalReview")
    @Deprecated
    public AjaxResult municipalReview(@RequestBody MunicipalReviewDto municipalReviewDto) {
        return success("市级评定结果确认成功" + bmsDeclarationRecordsService.municipalReview(municipalReviewDto) + "条数据");
    }

    @Log(title = "市级评定结果确认-new", businessType = BusinessType.UPDATE)
    @PutMapping("/municipalReviewNew")
    public AjaxResult municipalReviewNew(@RequestBody MunicipalReviewDto municipalReviewDto) {
        return success("市级评定结果确认成功" + bmsDeclarationRecordsService.municipalReviewNew(municipalReviewDto) + "条数据");
    }


    /**
     * 删除在线申报记录
     */
//    @RequiresPermissions("system:declarationRecords:remove")
    @Log(title = "在线申报记录", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(bmsDeclarationRecordsService.deleteBmsDeclarationRecordsByIds(ids));
    }
}
