package com.ruoyi.jjh.declaration.controller;

import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.jjh.declaration.entity.BmsIntegrationIndustries;
import com.ruoyi.jjh.declaration.entity.dto.BmsIntegrationIndustriesAddDto;
import com.ruoyi.jjh.declaration.entity.dto.BmsIntegrationIndustriesUpdateDto;
import com.ruoyi.jjh.declaration.service.IBmsIntegrationIndustriesService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 两业融合奖补Controller
 * 
 * @author farben
 * @date 2023-09-04
 */
@RestController
@RequestMapping("/system/integrationIndustries")
public class BmsIntegrationIndustriesController extends BaseController {
    @Autowired
    private IBmsIntegrationIndustriesService bmsIntegrationIndustriesService;

    /**
     * 查询两业融合奖补列表
     */
//    @RequiresPermissions("system:integrationIndustries:list")
    @GetMapping("/list")
    public TableDataInfo list(BmsIntegrationIndustries bmsIntegrationIndustries) {
        startPage();
        List<BmsIntegrationIndustries> list = bmsIntegrationIndustriesService.selectBmsIntegrationIndustriesList(bmsIntegrationIndustries);
        return getDataTable(list);
    }

    /**
     * 导出两业融合奖补列表
     */
//    @RequiresPermissions("system:integrationIndustries:export")
    @Log(title = "两业融合奖补", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BmsIntegrationIndustries bmsIntegrationIndustries) {
        List<BmsIntegrationIndustries> list = bmsIntegrationIndustriesService.selectBmsIntegrationIndustriesList(bmsIntegrationIndustries);
        ExcelUtil<BmsIntegrationIndustries> util = new ExcelUtil<BmsIntegrationIndustries>(BmsIntegrationIndustries.class);
        util.exportExcel(response, list, "两业融合奖补数据");
    }

    /**
     * 获取两业融合奖补详细信息
     */
//    @RequiresPermissions("system:integrationIndustries:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(bmsIntegrationIndustriesService.selectBmsIntegrationIndustriesById(id));
    }

    /**
     * 新增两业融合奖补
     */
//    @RequiresPermissions("system:integrationIndustries:add")
    @Log(title = "两业融合奖补", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BmsIntegrationIndustriesAddDto bmsIntegrationIndustriesAddDto) {
        return toAjax(bmsIntegrationIndustriesService.insertBmsIntegrationIndustries(bmsIntegrationIndustriesAddDto));
    }

    /**
     * 修改两业融合奖补
     */
//    @RequiresPermissions("system:integrationIndustries:edit")
    @Log(title = "两业融合奖补", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BmsIntegrationIndustriesUpdateDto bmsIntegrationIndustriesUpdateDto) {
        return toAjax(bmsIntegrationIndustriesService.updateBmsIntegrationIndustries(bmsIntegrationIndustriesUpdateDto));
    }

    /**
     * 删除两业融合奖补
     */
//    @RequiresPermissions("system:integrationIndustries:remove")
    @Log(title = "两业融合奖补", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(bmsIntegrationIndustriesService.deleteBmsIntegrationIndustriesByIds(ids));
    }
}
