package com.ruoyi.jjh.declaration.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.jjh.declaration.entity.BmsCreditManagement;
import com.ruoyi.jjh.declaration.entity.BmsDeclarationRecords;
import com.ruoyi.jjh.declaration.entity.dto.BmsCreditManagementAddDto;
import com.ruoyi.jjh.declaration.entity.dto.BmsCreditManagementUpdateDto;
import com.ruoyi.jjh.declaration.entity.vo.BmsBigStrongAwardQueryVo;
import com.ruoyi.jjh.declaration.entity.vo.DeclarationRecordsVo;
import com.ruoyi.jjh.declaration.mapper.BmsCreditManagementMapper;
import com.ruoyi.jjh.declaration.service.IBmsCreditManagementService;
import com.ruoyi.jjh.declaration.service.IBmsDeclarationRecordsService;
import com.ruoyi.jjh.declaration.service.ICommonService;
import com.ruoyi.jjh.ent.entity.JProject;
import com.ruoyi.jjh.ent.service.JProjectService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;

/**
 * 信用管理奖补Service业务层处理
 * 
 * @author farben
 * @date 2023-09-04
 */
@Service
public class BmsCreditManagementServiceImpl extends ServiceImpl<BmsCreditManagementMapper,BmsCreditManagement> implements IBmsCreditManagementService {

    @Autowired
    private ICommonService iCommonService;

    @Autowired
    private IBmsDeclarationRecordsService iBmsDeclarationRecordsService;

    @Resource
    private JProjectService jProjectService;
    /**
     * 查询信用管理奖补
     * 
     * @param id 信用管理奖补主键
     * @return 信用管理奖补
     */
    @Override
    public BmsCreditManagement selectBmsCreditManagementById(Long id) {
        return baseMapper.selectBmsCreditManagementById(id);
    }

    /**
     * 查询信用管理奖补列表
     * 
     * @param bmsCreditManagement 信用管理奖补
     * @return 信用管理奖补
     */
    @Override
    public List<BmsCreditManagement> selectBmsCreditManagementList(BmsCreditManagement bmsCreditManagement) {
        return baseMapper.selectBmsCreditManagementList(bmsCreditManagement);
    }

    /**
     * 新增信用管理奖补
     * 
     * @param bmsCreditManagementAddDto 信用管理奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int insertBmsCreditManagement(BmsCreditManagementAddDto bmsCreditManagementAddDto) {
        Long enterpriseId = iCommonService.checkEnterprise(bmsCreditManagementAddDto.getCreditCode()
                ,bmsCreditManagementAddDto.getTemplateRecordId());
        // check 申报信息
        iCommonService.checkDeclaration(bmsCreditManagementAddDto.getCreditCode()
                ,bmsCreditManagementAddDto.getTemplateRecordId());
        BmsCreditManagement bmsCreditManagement = new BmsCreditManagement();
        BeanUtil.copyProperties(bmsCreditManagementAddDto,bmsCreditManagement);
        bmsCreditManagement.setEnterpriseId(enterpriseId);
        // 新增做大做强奖详情
        int num = baseMapper.insert(bmsCreditManagement);

        // 新增申请记录
        BmsDeclarationRecords declarationRecords = new BmsDeclarationRecords();
        BeanUtil.copyProperties(bmsCreditManagementAddDto,declarationRecords);
        declarationRecords.setMatter("提交信用管理奖补申请");
        declarationRecords.setEnterpriseId(enterpriseId);
        declarationRecords.setDetailId(bmsCreditManagement.getId());
        iBmsDeclarationRecordsService.save(declarationRecords);

        //获取该申报记录的详情
        DeclarationRecordsVo declarationRecordsVo = iBmsDeclarationRecordsService.selectBmsDeclarationRecordsById(declarationRecords.getId());
        //申报的企业信息JSON
        String js1= JSONObject.toJSONString(declarationRecordsVo.getBmsEnterpriseBasicInfo());
        //在线申报信息JSON
        String js2 = JSONObject.toJSONString(declarationRecordsVo.getBmsDeclarationRecords());
        //信用管理奖补
        BmsCreditManagement p1 = declarationRecordsVo.getBmsCreditManagement();
        //信用管理奖补JSON
//        String js3 = JSONObject.toJSONString(p1);
        String str = jProjectService.allJsonString(js1, js2, "{}", "{}");
        String str1 = "{" +
                '"' + "项目方案" + '"' + ":" + '"' + p1.getProjectPlan() + '"' + ","+
                '"' + "资金使用说明" + '"' + ":" + '"' + p1.getUsesFunds() + '"' + ","+
                '"' + "项目专项审计报告" + '"' + ":" + '"' + p1.getAuditReport() + '"' + ","+
                "}";

        //新增项目
        JProject jP = new JProject();
        jP.setProjectYear(declarationRecords.getYear());
        jP.setProjectName(declarationRecords.getProjectName());
        jP.setDeclareUnit(declarationRecordsVo.getBmsEnterpriseBasicInfo().getEnterpriseName());
        jP.setProjectClassify(7);
        jP.setStatus(1);
        jP.setOtherJson(str);
        jP.setFileJson(str1);
        jProjectService.saveProject(jP,declarationRecords.getId());

        // 生成审核
        if (bmsCreditManagementAddDto.getStatus()==1){
            // 审批状态
            iCommonService.insertAuditRecord(declarationRecords.getId(),0);
        }
        return num;
    }

    /**
     * 修改信用管理奖补
     * 
     * @param bmsCreditManagementUpdateDto 信用管理奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int updateBmsCreditManagement(BmsCreditManagementUpdateDto bmsCreditManagementUpdateDto) {
        int num = 0;
        try {
            iBmsDeclarationRecordsService.updateDeclarationRecords(bmsCreditManagementUpdateDto.getDeclarationRecordsId()
                    ,bmsCreditManagementUpdateDto.getProjectId(),bmsCreditManagementUpdateDto.getProjectName()
                    ,bmsCreditManagementUpdateDto.getStatus());

            bmsCreditManagementUpdateDto.setUpdateTime(DateUtils.getNowDate());
            num =  baseMapper.updateBmsCreditManagement(bmsCreditManagementUpdateDto);
            // 申请审批
            if (bmsCreditManagementUpdateDto.getStatus()==1){
                // 审批状态
                iCommonService.insertAuditRecord(bmsCreditManagementUpdateDto.getDeclarationRecordsId(),0);
            }
        }catch (Exception e){
            e.printStackTrace();
        }
        return num;
    }

    /**
     * 批量删除信用管理奖补
     * 
     * @param ids 需要删除的信用管理奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsCreditManagementByIds(Long[] ids) {
        return baseMapper.deleteBmsCreditManagementByIds(ids);
    }

    /**
     * 删除信用管理奖补信息
     * 
     * @param id 信用管理奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsCreditManagementById(Long id) {
        return baseMapper.deleteBmsCreditManagementById(id);
    }
}
