package com.ruoyi.jjh.declaration.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.jjh.declaration.entity.BmsDeclarationRecords;
import com.ruoyi.jjh.declaration.entity.BmsLogisticsDevelopmentAward;
import com.ruoyi.jjh.declaration.entity.dto.BmsLogisticsDevelopmentAwardAddDto;
import com.ruoyi.jjh.declaration.entity.dto.BmsLogisticsDevelopmentAwardUpdateDto;
import com.ruoyi.jjh.declaration.entity.vo.BmsBigStrongAwardQueryVo;
import com.ruoyi.jjh.declaration.entity.vo.DeclarationRecordsVo;
import com.ruoyi.jjh.declaration.mapper.BmsLogisticsDevelopmentAwardMapper;
import com.ruoyi.jjh.declaration.service.IBmsDeclarationRecordsService;
import com.ruoyi.jjh.declaration.service.IBmsLogisticsDevelopmentAwardService;
import com.ruoyi.jjh.declaration.service.ICommonService;
import com.ruoyi.jjh.ent.entity.JProject;
import com.ruoyi.jjh.ent.service.JProjectService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;

/**
 * 物流发展奖补Service业务层处理
 * 
 * @author farben
 * @date 2023-08-25
 */
@Service
public class BmsLogisticsDevelopmentAwardServiceImpl extends ServiceImpl<BmsLogisticsDevelopmentAwardMapper,BmsLogisticsDevelopmentAward> implements IBmsLogisticsDevelopmentAwardService {

    @Autowired
    private ICommonService iCommonService;

    @Autowired
    private IBmsDeclarationRecordsService iBmsDeclarationRecordsService;

    @Resource
    private JProjectService jProjectService;
    /**
     * 查询物流发展奖补
     * 
     * @param id 物流发展奖补主键
     * @return 物流发展奖补
     */
    @Override
    public BmsLogisticsDevelopmentAward selectBmsLogisticsDevelopmentAwardById(Long id) {
        return baseMapper.selectBmsLogisticsDevelopmentAwardById(id);
    }

    /**
     * 查询物流发展奖补列表
     * 
     * @param bmsLogisticsDevelopmentAward 物流发展奖补
     * @return 物流发展奖补
     */
    @Override
    public List<BmsLogisticsDevelopmentAward> selectBmsLogisticsDevelopmentAwardList(BmsLogisticsDevelopmentAward bmsLogisticsDevelopmentAward) {
        return baseMapper.selectBmsLogisticsDevelopmentAwardList(bmsLogisticsDevelopmentAward);
    }

    /**
     * 新增物流发展奖补
     * 
     * @param bmsLogisticsDevelopmentAwardAddDto 物流发展奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int insertBmsLogisticsDevelopmentAward(BmsLogisticsDevelopmentAwardAddDto bmsLogisticsDevelopmentAwardAddDto) {
        Long enterpriseId = iCommonService.checkEnterprise(bmsLogisticsDevelopmentAwardAddDto.getCreditCode()
                ,bmsLogisticsDevelopmentAwardAddDto.getTemplateRecordId());
        // check 申报信息
        iCommonService.checkDeclaration(bmsLogisticsDevelopmentAwardAddDto.getCreditCode()
                ,bmsLogisticsDevelopmentAwardAddDto.getTemplateRecordId());
        BmsLogisticsDevelopmentAward bmsLogisticsDevelopmentAward = new BmsLogisticsDevelopmentAward();

        BeanUtil.copyProperties(bmsLogisticsDevelopmentAwardAddDto,bmsLogisticsDevelopmentAward);
        bmsLogisticsDevelopmentAward.setEnterpriseId(enterpriseId);
        // 新增做大做强奖详情
        int num = baseMapper.insert(bmsLogisticsDevelopmentAward);

        // 新增申请记录
        BmsDeclarationRecords declarationRecords = new BmsDeclarationRecords();
        BeanUtil.copyProperties(bmsLogisticsDevelopmentAwardAddDto,declarationRecords);
        declarationRecords.setMatter("提交物流发展奖补申请");
        declarationRecords.setEnterpriseId(enterpriseId);
        declarationRecords.setDetailId(bmsLogisticsDevelopmentAward.getId());
        iBmsDeclarationRecordsService.save(declarationRecords);

        //获取该申报记录的详情
        DeclarationRecordsVo declarationRecordsVo = iBmsDeclarationRecordsService.selectBmsDeclarationRecordsById(declarationRecords.getId());
        //申报的企业信息JSON
        String js1= JSONObject.toJSONString(declarationRecordsVo.getBmsEnterpriseBasicInfo());
        //在线申报信息JSON
        String js2 = JSONObject.toJSONString(declarationRecordsVo.getBmsDeclarationRecords());
        //物流发展奖补
        BmsLogisticsDevelopmentAward p1  = declarationRecordsVo.getBmsLogisticsDevelopmentAward();
        //物流发展奖补JSON
//        String js3 = JSONObject.toJSONString(p1);
        String str = jProjectService.allJsonString(js1, js2, "{}", "{}");
        String str1 = "{" +
                '"' + "荣誉证明文件" + '"' + ":" + '"' + p1.getHonorCertificate() + '"' + ","+
                '"' + "平台名称" + '"' + ":" + '"' + p1.getPlatformName() + '"' + ","+
                '"' + "企业投资项目备案通知书或核准批复文件" + '"' + ":" + '"' + p1.getFilingNotice() + '"' + ","+
                '"' + "会计师事务所出具的企业财务报表审计报告" + '"' + ":" + '"' + p1.getAuditReport() + '"' +
                "}";

        //新增项目
        JProject jP = new JProject();
        jP.setProjectYear(declarationRecords.getYear());
        jP.setProjectName(declarationRecords.getProjectName());
        jP.setDeclareUnit(declarationRecordsVo.getBmsEnterpriseBasicInfo().getEnterpriseName());
        jP.setProjectClassify(9);
        jP.setStatus(1);
        jP.setOtherJson(str);
        jP.setFileJson(str1);
        jProjectService.saveProject(jP,declarationRecords.getId());

        // 生成审核
        if (bmsLogisticsDevelopmentAwardAddDto.getStatus()==1){
            // 审批状态
            iCommonService.insertAuditRecord(declarationRecords.getId(),0);
        }
        return num;
    }

    /**
     * 修改物流发展奖补
     * 
     * @param bmsLogisticsDevelopmentAwardUpdateDto 物流发展奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int updateBmsLogisticsDevelopmentAward(BmsLogisticsDevelopmentAwardUpdateDto bmsLogisticsDevelopmentAwardUpdateDto) {
        int num = 0;
        try {
            iBmsDeclarationRecordsService.updateDeclarationRecords(bmsLogisticsDevelopmentAwardUpdateDto.getDeclarationRecordsId()
                    ,bmsLogisticsDevelopmentAwardUpdateDto.getProjectId(),bmsLogisticsDevelopmentAwardUpdateDto.getProjectName()
                    ,bmsLogisticsDevelopmentAwardUpdateDto.getStatus());

            iBmsDeclarationRecordsService.updateProjectNameById(bmsLogisticsDevelopmentAwardUpdateDto.getId()
                    ,bmsLogisticsDevelopmentAwardUpdateDto.getProjectName(),bmsLogisticsDevelopmentAwardUpdateDto.getProjectId());
            bmsLogisticsDevelopmentAwardUpdateDto.setUpdateTime(DateUtils.getNowDate());
            num = baseMapper.updateBmsLogisticsDevelopmentAward(bmsLogisticsDevelopmentAwardUpdateDto);
            // 申请审批
            if (bmsLogisticsDevelopmentAwardUpdateDto.getStatus()==1){
                // 审批状态
                iCommonService.insertAuditRecord(bmsLogisticsDevelopmentAwardUpdateDto.getDeclarationRecordsId(),0);
            }
        }catch (Exception e){
            e.printStackTrace();
        }
        return num;
    }

    /**
     * 批量删除物流发展奖补
     * 
     * @param ids 需要删除的物流发展奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsLogisticsDevelopmentAwardByIds(Long[] ids) {
        return baseMapper.deleteBmsLogisticsDevelopmentAwardByIds(ids);
    }

    /**
     * 删除物流发展奖补信息
     * 
     * @param id 物流发展奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsLogisticsDevelopmentAwardById(Long id) {
        return baseMapper.deleteBmsLogisticsDevelopmentAwardById(id);
    }
}
